@@ -119,6 +119,25 @@ def delete_nanfilled_cols(data, cutoff=.90, exclude=False, inplace=False):
         df = data.drop(columns=cols_to_delete[cols_to_delete == True].index).copy()
         return df
 
+def delete_nanfilled_lines(data, variables=False, inplace=False, count=True):
+    """Suppression des colomnes avec un certain seuil de nan
+
+    Keyword arguments:
+    data -- le dataFrame
+    variables -- array of variables to survey
+    inplace -- suppression "inplace" ou non
+    """
+    if count:
+      datasize = data.shape[0]
+    if inplace:
+      df_union.dropna(subset=variables, how="all", inplace=True)
+      if count:
+        print(f"\033[1m{datasize - df_union.shape[0]} lignes ont été supprimées.\033[0m")
+    else:
+      if count:
+        print(f"\033[1m{datasize - df_union.shape[0]} lignes ont été supprimées.\033[0m")
+      return df_union.dropna(subset=variables, how="all")
+      
 def df_description(data, col_count=False, return_only=False):
     """Description des variables enrichie de 2 colonnes = nombre de nan et % de nan
     
